@@ -58,7 +58,7 @@ KW_RESPONSE = '__KW_RESPONSE__'
 
 DOCUMENTATION_ENDPOINT = f'{c.SLASH}{KW_OPEN_API}'
 ZERO_DOT_ZERO_DOT_ZERO_DOT_ZERO_HOST = "0.0.0.0"
-LOCALHOST_HOST =S 'localhost'
+LOCALHOST_HOST = 'localhost'
 SCHEME_HOST_SEPARATOR = '://'
 DEFAULT_DOCUMENTATION_PORT = '80'
 PORT_80_IN_URL = ':80/'
